@@ -12,29 +12,41 @@ def render(tpl_path, context):
 ####
 
 types_l=['real', 'complex']
-nranks=4
-kinds_l= [{'name':'dp', 'val':'selected_real_kind(14,200)'}, 
-          {'name':'sp', 'val':'selected_real_kind(6, 37)'}]
+nranks=6
+kinds_l= [{'name':'dp', 'val':'real64'},
+          {'name':'sp', 'val':'real32'}]
 
-# Generate subroutines
-with open('device_auxfunc.f90', 'w') as f:
-    f.write(render('device_auxfunc.jf90', 
+# Generate module
+with open('devxlib_auxfunc.f90', 'w') as f:
+    f.write(render('devxlib_auxfunc.jf90',
                     {'types' : types_l, 'dimensions': nranks, 'precision' : kinds_l }
                   ))
 
-# Generate interfaces
-with open('device_auxfunc_interf.f90', 'w') as f:
-    f.write(render('device_auxfunc_interf.jf90', 
+# Generate submodules
+with open('devxlib_auxfunc_vec_upd.f90', 'w') as f:
+    f.write(render('devxlib_auxfunc_vec_upd.jf90',
                     {'types' : types_l, 'dimensions': nranks, 'precision' : kinds_l }
                   ))
-            
+with open('devxlib_auxfunc_mat_upd.f90', 'w') as f:
+    f.write(render('devxlib_auxfunc_mat_upd.jf90',
+                    {'types' : types_l, 'dimensions': nranks, 'precision' : kinds_l }
+                  ))
+with open('devxlib_auxfunc_addscal.f90', 'w') as f:
+    f.write(render('devxlib_auxfunc_addscal.jf90',
+                    {'types' : types_l, 'dimensions': nranks, 'precision' : kinds_l }
+                  ))
+with open('devxlib_auxfunc_conjg.f90', 'w') as f:
+    f.write(render('devxlib_auxfunc_conjg.jf90',
+                    {'types' : types_l, 'dimensions': nranks, 'precision' : kinds_l }
+                  ))
+
 ## Generate tests
 #with open('test_auxfunc.f90', 'w') as f:
-#    f.write(render('test_auxfunc.jf90', 
+#    f.write(render('test_auxfunc.jf90',
 #                    {'types' : types_l, 'dimensions': nranks, 'precision' : kinds_l }
 #                  ))
 
-# set multiple extensions
-copyfile("device_auxfunc.f90","device_auxfunc.F")
-copyfile("device_auxfunc_interf.f90","device_auxfunc_interf.F")
+## set multiple extensions
+#copyfile("device_auxfunc.f90","device_auxfunc.F")
+#copyfile("device_auxfunc_interf.f90","device_auxfunc_interf.F")
 
